@@ -3,13 +3,17 @@
 import argparse
 import os
 import re
+import sys
+from multiprocessing import cpu_count
 from pathlib import Path
 from typing import List, Optional
 
 import cli_ui as ui
 
-import tsrc
-from tsrc import Manifest, Workspace
+from tsrc.errors import Error
+from tsrc.manifest import Manifest
+from tsrc.repo import Repo
+from tsrc.workspace import Workspace
 from tsrc.workspace.config import WorkspaceConfig
 
 
@@ -23,9 +27,31 @@ def add_workspace_arg(parser: argparse.ArgumentParser) -> None:
     )
 
 
+def add_num_jobs_arg(parser: argparse.ArgumentParser) -> None:
+    parser.add_argument(
+        "-j",
+        "--jobs",
+        dest="num_jobs",
+        help="Number of jobs to use simultaneously",
+    )
+
+
+def get_num_jobs(args: argparse.Namespace) -> Optional[int]:
+    value = args.num_jobs
+    if value is None:
+        return None
+    if value == "auto":
+        return cpu_count()
+    try:
+        return int(value)
+    except ValueError:
+        sys.exit(f"error: argument -j/--jobs: invalid value: {value}")
+
+
 def get_workspace(namespace: argparse.Namespace) -> Workspace:
     workspace_path = namespace.workspace_path or find_workspace_path()
-    return tsrc.Workspace(workspace_path)
+    ui.info_1("Using workspace in", ui.bold, workspace_path)
+    return Workspace(workspace_path)
 
 
 def add_groups_arg(parser: argparse.ArgumentParser) -> None:
@@ -66,7 +92,7 @@ def find_workspace_path() -> Path:
 
         else:
             head, tail = os.path.split(head)
-    raise tsrc.Error("Could not find current workspace")
+    raise Error("Could not find current workspace")
 
 
 def get_workspace_with_repos(namespace: argparse.Namespace) -> Workspace:
@@ -87,8 +113,8 @@ def resolve_repos(
     groups: Optional[List[str]],
     all_cloned: bool,
     regex: str = "",
-    iregex: str = ""
-) -> List[tsrc.Repo]:
+    iregex: str = "",
+) -> List[Repo]:
     """
     Given a workspace with its config and its local manifest,
     and a collection of parsed command  line arguments,
@@ -119,7 +145,7 @@ def resolve_repos(
 
 def repos_from_config(
     manifest: Manifest, workspace_config: WorkspaceConfig
-) -> List[tsrc.Repo]:
+) -> List[Repo]:
     """
     Given a workspace config, returns a list of repos.
 
