@@ -4,21 +4,21 @@
 import os
 import subprocess
 from pathlib import Path
-from typing import Any, Dict, Iterable, List, Optional, Tuple  # noqa
+from typing import Any, Dict, Iterable, List, Optional, Tuple
 
 import cli_ui as ui
 
-import tsrc
+from tsrc.errors import Error
 
 UP = ui.Symbol("↑", "+").as_string
 DOWN = ui.Symbol("↓", "-").as_string
 
 
-class Error(tsrc.Error):
+class GitError(Error):
     pass
 
 
-class CommandError(Error):
+class GitCommandError(GitError):
     def __init__(
         self, working_path: Path, cmd: Iterable[str], *, output: Optional[str] = None
     ) -> None:
@@ -32,12 +32,12 @@ class CommandError(Error):
         super().__init__(message)
 
 
-class NoSuchWorkingPath(Error):
+class NoSuchWorkingPath(GitError):
     def __init__(self, path: Path) -> None:
         super().__init__(f"'{path}' does not exist")
 
 
-class WorktreeNotFound(Error):
+class WorktreeNotFound(GitError):
     def __init__(self, working_path: Path) -> None:
         super().__init__(f"'{working_path}' is not inside a git repository")
 
@@ -47,7 +47,7 @@ def assert_working_path(path: Path) -> None:
         raise NoSuchWorkingPath(path)
 
 
-class Status:
+class GitStatus:
     """Represent a status of a git repo.
 
     Usage:
@@ -67,16 +67,16 @@ class Status:
         self.ahead = 0
         self.behind = 0
         self.dirty = False
-        self.tag = None  # type: Optional[str]
-        self.branch = None  # type: Optional[str]
-        self.sha1 = None  # type: Optional[str]
+        self.tag: Optional[str] = None
+        self.branch: Optional[str] = None
+        self.sha1: Optional[str] = None
 
     def update(self) -> None:
         # Try and gather as many information about the git repository as
         # possible.
         try:
             self.update_sha1()
-        except CommandError:
+        except GitCommandError:
             self.empty = True
             return
         self.update_branch()
@@ -90,30 +90,30 @@ class Status:
     def update_branch(self) -> None:
         try:
             self.branch = get_current_branch(self.working_path)
-        except Error:
+        except GitError:
             pass
 
     def update_tag(self) -> None:
         try:
             self.tag = get_current_tag(self.working_path)
-        except Error:
+        except GitError:
             pass
 
     def update_remote_status(self) -> None:
-        rc, ahead_rev = run_captured(
+        rc, ahead_rev = run_git_captured(
             self.working_path, "rev-list", "@{upstream}..HEAD", check=False
         )
         if rc == 0:
             self.ahead = len(ahead_rev.splitlines())
 
-        rc, behind_rev = run_captured(
+        rc, behind_rev = run_git_captured(
             self.working_path, "rev-list", "HEAD..@{upstream}", check=False
         )
         if rc == 0:
             self.behind = len(behind_rev.splitlines())
 
     def update_worktree_status(self) -> None:
-        _, out = run_captured(self.working_path, "status", "--porcelain")
+        _, out = run_git_captured(self.working_path, "status", "--porcelain")
 
         for line in out.splitlines():
             if line.startswith("??"):
@@ -131,7 +131,7 @@ class Status:
 
     def describe(self) -> List[ui.Token]:
         """Return a list of tokens suitable for ui.info."""
-        res = []  # type: List[ui.Token]
+        res: List[ui.Token] = []
         if self.empty:
             return [ui.red, "empty"]
         res += self.describe_branch()
@@ -140,7 +140,7 @@ class Status:
         return res
 
     def describe_branch(self) -> List[ui.Token]:
-        res = []  # type: List[ui.Token]
+        res: List[ui.Token] = []
         if self.branch:
             res += [ui.green, self.branch, ui.reset]
         elif self.sha1:
@@ -164,26 +164,28 @@ class Status:
         as a list of tokens suitable for `ui.info()`.
 
         """
-        res = []  # type: List[ui.Token]
+        res: List[ui.Token] = []
         if self.ahead != 0:
-            n_commits = Status.commit_string(self.ahead)
+            n_commits = GitStatus.commit_string(self.ahead)
             ahead_desc = f"{UP}{self.ahead} {n_commits}"
             res += [ui.blue, ahead_desc, ui.reset]
         if self.behind != 0:
-            n_commits = Status.commit_string(self.behind)
+            n_commits = GitStatus.commit_string(self.behind)
             behind_desc = f"{DOWN}{self.behind} {n_commits}"
             res += [ui.blue, behind_desc, ui.reset]
         return res
 
     def describe_dirty(self) -> List[ui.Token]:
         """Add the `(dirty)` colored string if the repo is dirty."""
-        res = []  # type: List[ui.Token]
+        res: List[ui.Token] = []
         if self.dirty:
             res += [ui.red, "(dirty)", ui.reset]
         return res
 
 
-def run(working_path: Path, *cmd: str, check: bool = True) -> None:
+def run_git(
+    working_path: Path, *cmd: str, check: bool = True, verbose: bool = True
+) -> None:
     """Run git `cmd` in given `working_path`.
 
     Raise GitCommandError if return code is non-zero and `check` is True.
@@ -193,12 +195,23 @@ def run(working_path: Path, *cmd: str, check: bool = True) -> None:
     git_cmd.insert(0, "git")
 
     ui.debug(ui.lightgray, working_path, "$", ui.reset, *git_cmd)
-    returncode = subprocess.call(git_cmd, cwd=working_path)
-    if returncode != 0 and check:
-        raise CommandError(working_path, cmd)
+    if verbose:
+        process = subprocess.run(git_cmd, cwd=working_path, universal_newlines=True)
+    else:
+        process = subprocess.run(
+            git_cmd,
+            cwd=working_path,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+            universal_newlines=True,
+        )
+    if process.returncode != 0 and check:
+        raise GitCommandError(working_path, cmd, output=process.stdout)
 
 
-def run_captured(working_path: Path, *cmd: str, check: bool = True) -> Tuple[int, str]:
+def run_git_captured(
+    working_path: Path, *cmd: str, check: bool = True
+) -> Tuple[int, str]:
     """Run git `cmd` in given `working_path`, capturing the output.
 
     Return a tuple (returncode, output).
@@ -208,7 +221,7 @@ def run_captured(working_path: Path, *cmd: str, check: bool = True) -> Tuple[int
     assert_working_path(working_path)
     git_cmd = list(cmd)
     git_cmd.insert(0, "git")
-    options = {}  # type: Dict[str, Any]
+    options: Dict[str, Any] = {}
     options["stdout"] = subprocess.PIPE
     options["stderr"] = subprocess.STDOUT
 
@@ -221,7 +234,7 @@ def run_captured(working_path: Path, *cmd: str, check: bool = True) -> Tuple[int
     returncode = process.returncode
     ui.debug(ui.lightgray, "[", returncode, "]", ui.reset, out)
     if check and returncode != 0:
-        raise CommandError(working_path, cmd, output=out)
+        raise GitCommandError(working_path, cmd, output=out)
     return returncode, out
 
 
@@ -230,21 +243,21 @@ def get_sha1(working_path: Path, short: bool = False, ref: str = "HEAD") -> str:
     if short:
         cmd.append("--short")
     cmd.append(ref)
-    _, output = run_captured(working_path, *cmd)
+    _, output = run_git_captured(working_path, *cmd)
     return output
 
 
 def get_current_branch(working_path: Path) -> str:
     cmd = ("rev-parse", "--abbrev-ref", "HEAD")
-    _, output = run_captured(working_path, *cmd)
+    _, output = run_git_captured(working_path, *cmd)
     if output == "HEAD":
-        raise Error("Not an any branch")
+        raise GitError("Not an any branch")
     return output
 
 
 def get_current_tag(working_path: Path) -> str:
     cmd = ("tag", "--points-at", "HEAD")
-    _, output = run_captured(working_path, *cmd)
+    _, output = run_git_captured(working_path, *cmd)
     return output
 
 
@@ -252,7 +265,7 @@ def get_repo_root(working_path: Optional[Path] = None) -> Path:
     if not working_path:
         working_path = Path(os.getcwd())
     cmd = ("rev-parse", "--show-toplevel")
-    status, output = run_captured(working_path, *cmd, check=False)
+    status, output = run_git_captured(working_path, *cmd, check=False)
     if status != 0:
         raise WorktreeNotFound(working_path)
     return Path(output)
@@ -260,29 +273,36 @@ def get_repo_root(working_path: Optional[Path] = None) -> Path:
 
 def find_ref(repo: Path, candidate_refs: Iterable[str]) -> str:
     """Find the first reference that exists in the given repo"""
-    run(repo, "fetch", "--all", "--prune")
+    run_git(repo, "fetch", "--all", "--prune")
     for candidate_ref in candidate_refs:
-        code, _ = run_captured(repo, "rev-parse", candidate_ref, check=False)
+        code, _ = run_git_captured(repo, "rev-parse", candidate_ref, check=False)
         if code == 0:
             return candidate_ref
     ref_list = ", ".join(candidate_refs)
-    raise Error("Could not find any of:", ref_list, "in repo", repo)
+    raise GitError("Could not find any of:", ref_list, "in repo", repo)
 
 
-def reset(repo: Path, ref: str) -> None:
+def git_reset(repo: Path, ref: str) -> None:
     ui.info_2("Resetting", repo, "to", ref)
-    run(repo, "reset", "--hard", ref)
+    run_git(repo, "reset", "--hard", ref)
 
 
-def get_status(working_path: Path) -> Status:
-    status = Status(working_path)
+def get_git_status(working_path: Path) -> GitStatus:
+    status = GitStatus(working_path)
     status.update()
     return status
 
 
+def is_git_repository(working_path: Path) -> bool:
+    if not working_path.is_dir():
+        return False
+    rc, _ = run_git_captured(working_path, "rev-parse", "--git-dir", check=False)
+    return rc == 0
+
+
 def get_tracking_ref(working_path: Path) -> Optional[str]:
     # fmt: off
-    rc, out = run_captured(
+    rc, out = run_git_captured(
         working_path,
         "rev-parse", "--abbrev-ref",
         "--symbolic-full-name", "@{upstream}",
@@ -297,5 +317,5 @@ def get_tracking_ref(working_path: Path) -> Optional[str]:
 
 def is_shallow(working_path: Path) -> bool:
     root = get_repo_root(working_path)
-    res = (root / ".git/shallow").exists()  # type: bool
+    res = (root / ".git/shallow").exists()
     return res
