@@ -5,10 +5,12 @@ from typing import Any
 import ruamel.yaml
 from cli_ui.tests import MessageRecorder
 
-import tsrc.cli
+from tsrc.errors import Error
+from tsrc.git import get_sha1, run_git, run_git_captured
 from tsrc.groups import GroupNotFound
 from tsrc.test.helpers.cli import CLI
 from tsrc.test.helpers.git_server import GitServer
+from tsrc.workspace import SyncError
 from tsrc.workspace.config import WorkspaceConfig
 
 
@@ -32,6 +34,30 @@ def test_sync_happy(tsrc_cli: CLI, git_server: GitServer, workspace_path: Path)
     assert new_txt_path.exists(), "foo should have been updated"
 
 
+def test_sync_parallel(
+    tsrc_cli: CLI, git_server: GitServer, workspace_path: Path
+) -> None:
+    """
+    Run `tsrc` with 2 jobs on three repos, two of which have changed
+
+    This is useful to check tsrc output when running tasks in parallel
+    """
+    git_server.add_repo("foo")
+    git_server.add_repo("bar")
+    git_server.add_repo("baz")
+    manifest_url = git_server.manifest_url
+
+    tsrc_cli.run("init", manifest_url, "-j", "2")
+
+    baz_path = workspace_path / "baz"
+    run_git(baz_path, "remote", "set-url", "origin", "other@domain.tld/baz")
+    git_server.push_file("foo", "foo.txt")
+    git_server.push_file("bar", "bar1")
+    git_server.push_file("bar", "bar2", contents="two\nlines\n")
+
+    tsrc_cli.run("sync", "-j", "2")
+
+
 def test_sync_with_errors(
     tsrc_cli: CLI,
     git_server: GitServer,
@@ -56,10 +82,23 @@ def test_sync_with_errors(
     foo_src = workspace_path / "foo"
     (foo_src / "conflict.txt").write_text("this is green")
 
-    tsrc_cli.run_and_fail("sync")
+    tsrc_cli.run_and_fail_with(Error, "sync")
 
-    assert message_recorder.find("Failed to synchronize workspace")
-    assert message_recorder.find(r"\* foo")
+
+def test_sync_on_bare_repo(
+    tsrc_cli: CLI,
+    git_server: GitServer,
+    workspace_path: Path,
+) -> None:
+    git_server.add_repo("foo")
+    manifest_url = git_server.manifest_url
+
+    foo_path = workspace_path / "foo"
+    foo_path.mkdir(parents=True)
+    run_git(foo_path, "init", "--bare")
+
+    tsrc_cli.run("init", manifest_url)
+    tsrc_cli.run_and_fail_with(SyncError, "sync")
 
 
 def test_sync_finds_root(
@@ -155,13 +194,13 @@ def test_sync_not_on_master(
     tsrc_cli.run("init", manifest_url)
 
     foo_path = workspace_path / "foo"
-    tsrc.git.run(foo_path, "checkout", "-B", "devel")
-    tsrc.git.run(foo_path, "branch", "--set-upstream-to", "origin/devel")
+    run_git(foo_path, "checkout", "-B", "devel")
+    run_git(foo_path, "branch", "--set-upstream-to", "origin/devel")
 
     tsrc_cli.run_and_fail("sync")
 
     assert (foo_path / "devel.txt").exists(), "foo should have been updated"
-    assert message_recorder.find("not on the correct branch")
+    assert message_recorder.find("does not match")
 
 
 def test_sync_with_force(
@@ -360,7 +399,7 @@ def test_changing_branch(
     git_server.manifest.set_repo_branch("foo", "next")
 
     tsrc_cli.run_and_fail("sync")
-    assert message_recorder.find("not on the correct branch")
+    assert message_recorder.find("does not match")
 
 
 def test_tags_are_not_updated(
@@ -575,17 +614,21 @@ def test_fetch_additional_remotes(
     * Run `tsrc sync`
     * Check that the second remote was fetched
     """
-    git_server.add_repo("foo")
-    foo2_url = git_server.add_repo("foo2")
-    git_server.manifest.set_repo_remotes("foo", [("other", foo2_url)])
+    foo_url = git_server.add_repo("foo")
+    foo2_url = git_server.add_repo("foo2", add_to_manifest=False)
+    git_server.manifest.set_repo_remotes(
+        "foo", [("origin", foo_url), ("other", foo2_url)]
+    )
 
     tsrc_cli.run("init", git_server.manifest_url)
     foo_path = workspace_path / "foo"
-    first_sha1 = tsrc.git.get_sha1(foo_path, ref="other/master")
+    run_git(foo_path, "fetch", "other")
+    first_sha1 = get_sha1(foo_path, ref="other/master")
     git_server.push_file("foo2", "new.txt")
+    foo_path = workspace_path / "foo"
 
     tsrc_cli.run("sync")
-    second_sha1 = tsrc.git.get_sha1(foo_path, ref="other/master")
+    second_sha1 = get_sha1(foo_path, ref="other/master")
 
     assert first_sha1 != second_sha1, "remote 'other' was not fetched"
 
@@ -600,17 +643,17 @@ def test_adding_remotes(
     * Run `tsrc sync`
     * Check that the second remote was fetched
     """
-    git_server.add_repo("foo")
+    foo_url = git_server.add_repo("foo")
     tsrc_cli.run("init", git_server.manifest_url)
-    foo2_url = git_server.add_repo("foo2")
-    git_server.manifest.set_repo_remotes("foo", [("other", foo2_url)])
+    foo2_url = git_server.add_repo("foo2", add_to_manifest=False)
+    git_server.manifest.set_repo_remotes(
+        "foo", [("origin", foo_url), ("other", foo2_url)]
+    )
 
     tsrc_cli.run("sync")
 
     foo_path = workspace_path / "foo"
-    assert tsrc.git.get_sha1(
-        foo_path, ref="other/master"
-    ), "remote 'other' was not added"
+    assert get_sha1(foo_path, ref="other/master"), "remote 'other' was not added"
 
 
 def test_changing_remote_url(
@@ -626,12 +669,12 @@ def test_changing_remote_url(
     git_server.add_repo("foo")
     tsrc_cli.run("init", git_server.manifest_url)
 
-    foo2_url = git_server.add_repo("foo2")
+    foo2_url = git_server.add_repo("foo2", add_to_manifest=False)
     git_server.manifest.set_repo_url("foo", foo2_url)
     tsrc_cli.run("sync")
 
     foo_path = workspace_path / "foo"
-    _, actual_url = tsrc.git.run_captured(foo_path, "remote", "get-url", "origin")
+    _, actual_url = run_git_captured(foo_path, "remote", "get-url", "origin")
     assert actual_url == foo2_url, "remote was not updated"
 
 
