@@ -6,7 +6,8 @@ import pytest
 import ruamel.yaml
 import schema
 
-import tsrc
+from tsrc.config import parse_config
+from tsrc.errors import InvalidConfig
 
 
 def test_invalid_syntax(tmp_path: Path) -> None:
@@ -22,9 +23,9 @@ def test_invalid_syntax(tmp_path: Path) -> None:
         """
         )
     )
-    with pytest.raises(tsrc.InvalidConfig) as e:
+    with pytest.raises(InvalidConfig) as e:
         dummy_schema = mock.Mock()
-        tsrc.parse_config(foo_yml, schema=dummy_schema)
+        parse_config(foo_yml, schema=dummy_schema)
     raised_error = e.value
     assert raised_error.config_path == foo_yml
     assert isinstance(raised_error.cause, ruamel.yaml.error.YAMLError)
@@ -41,8 +42,8 @@ def test_invalid_schema(tmp_path: Path) -> None:
         )
     )
     foo_schema = schema.Schema({"foo": {"bar": str}})
-    with pytest.raises(tsrc.InvalidConfig) as e:
-        tsrc.parse_config(foo_yml, schema=foo_schema)
+    with pytest.raises(InvalidConfig) as e:
+        parse_config(foo_yml, schema=foo_schema)
     assert isinstance(e.value.cause, schema.SchemaError)
 
 
@@ -53,5 +54,5 @@ def test_use_pure_python_types(tmp_path: Path) -> None:
     foo_yml = tmp_path / "foo.yml"
     foo_yml.write_text("foo: 42\n")
     foo_schema = schema.Schema({"foo": int})
-    parsed = tsrc.parse_config(foo_yml, schema=foo_schema)
-    assert type(parsed) == type({})  # noqa
+    parsed = parse_config(foo_yml, schema=foo_schema)
+    assert parsed.__class__ == dict
