@@ -2,21 +2,22 @@
 """
 
 from pathlib import Path
-from typing import Iterable, List, Tuple
+from typing import Iterable, List, Optional, Tuple
 
 import cli_ui as ui
 import ruamel.yaml
 
-import tsrc
-import tsrc.executor
-import tsrc.git
-
-from .cloner import Cloner
-from .config import WorkspaceConfig
-from .file_system_operator import FileSystemOperator
-from .local_manifest import LocalManifest
-from .remote_setter import RemoteSetter
-from .syncer import Syncer
+from tsrc.errors import Error
+from tsrc.executor import process_items
+from tsrc.git import is_git_repository
+from tsrc.manifest import Manifest
+from tsrc.repo import Repo
+from tsrc.workspace.cloner import Cloner
+from tsrc.workspace.config import WorkspaceConfig
+from tsrc.workspace.file_system_operator import FileSystemOperator
+from tsrc.workspace.local_manifest import LocalManifest
+from tsrc.workspace.remote_setter import RemoteSetter
+from tsrc.workspace.syncer import Syncer
 
 
 def copy_cfg_path_if_needed(root_path: Path) -> None:
@@ -59,9 +60,9 @@ class Workspace:
         # the workspace and the requested repos - for instance, the user could
         # have configured a workspace with a `backend` group, but using
         # a disjoint `front-end` group on the command line.
-        self.repos: List[tsrc.Repo] = []
+        self.repos: List[Repo] = []
 
-    def get_manifest(self) -> tsrc.Manifest:
+    def get_manifest(self) -> Manifest:
         return self.local_manifest.get_manifest()
 
     def update_manifest(self) -> None:
@@ -69,51 +70,101 @@ class Workspace:
         manifest_branch = self.config.manifest_branch
         self.local_manifest.update(url=manifest_url, branch=manifest_branch)
 
-    def clone_missing(self) -> None:
+    def clone_missing(self, *, num_jobs: Optional[int] = None) -> None:
         to_clone = []
         for repo in self.repos:
             repo_path = self.root_path / repo.dest
-            if not repo_path.exists():
+            if not is_git_repository(repo_path):
                 to_clone.append(repo)
         cloner = Cloner(
             self.root_path,
             shallow=self.config.shallow_clones,
             remote_name=self.config.singular_remote,
         )
-        tsrc.executor.run_sequence(to_clone, cloner)
+        ui.info_2("Cloning missing repos")
+        collection = process_items(to_clone, cloner, num_jobs=num_jobs)
+        if collection.summary:
+            ui.info_2("Cloned repos:")
+            for summary in collection.summary:
+                ui.info(ui.green, "*", ui.reset, summary)
+        if collection.errors:
+            ui.error("Failed to clone the following repos")
+            collection.print_errors()
+            raise ClonerError
 
-    def set_remotes(self) -> None:
-        if not self.config.singular_remote:
-            remote_setter = RemoteSetter(self.root_path)
-            tsrc.executor.run_sequence(self.repos, remote_setter)
+    def set_remotes(self, num_jobs: Optional[int] = None) -> None:
+        if self.config.singular_remote:
+            return
+        ui.info_2("Configuring remotes")
+        remote_setter = RemoteSetter(self.root_path)
+        collection = process_items(self.repos, remote_setter, num_jobs=num_jobs)
+        collection.print_summary()
+        if collection.errors:
+            ui.error("Failed to set remotes for the following repos:")
+            collection.print_errors()
+            raise RemoteSetterError
 
-    def perform_filesystem_operations(self) -> None:
+    def perform_filesystem_operations(
+        self, manifest: Optional[Manifest] = None
+    ) -> None:
         repos = self.repos
+        if not manifest:
+            manifest = self.get_manifest()
         operator = FileSystemOperator(self.root_path, repos)
-        manifest = self.local_manifest.get_manifest()
         operations = manifest.file_system_operations
         known_repos = [x.dest for x in repos]
         operations = [x for x in operations if x.repo in known_repos]  # type: ignore
-        tsrc.executor.run_sequence(operations, operator)
+        if operations:
+            ui.info_2("Performing filesystem operations")
+            # Not sure it's a good idea to have FileSystemOperations running in parallel
+            collection = process_items(operations, operator, num_jobs=None)
+            collection.print_summary()
+            if collection.errors:
+                ui.error("Failed to perform the following file system operations")
+                collection.print_errors()
+                raise FileSystemOperatorError
 
-    def sync(self, *, force: bool = False) -> None:
+    def sync(self, *, force: bool = False, num_jobs: Optional[int] = None) -> None:
         syncer = Syncer(
             self.root_path, force=force, remote_name=self.config.singular_remote
         )
         repos = self.repos
-        try:
-            tsrc.executor.run_sequence(repos, syncer)
-        finally:
-            syncer.display_bad_branches()
+        ui.info_2("Synchronizing repos")
+        collection = process_items(repos, syncer, num_jobs=num_jobs)
+        if collection.summary:
+            ui.info_2("Updated repos:")
+            for summary in collection.summary:
+                if summary:
+                    ui.info(summary)
+        if collection.errors:
+            ui.error("Failed to synchronize the following repos:")
+            collection.print_errors()
+            raise SyncError
 
-    def enumerate_repos(self) -> Iterable[Tuple[int, tsrc.Repo, Path]]:
+    def enumerate_repos(self) -> Iterable[Tuple[int, Repo, Path]]:
         """Yield (index, repo, full_path) for all the repos"""
         for i, repo in enumerate(self.repos):
             full_path = self.root_path / repo.dest
             yield (i, repo, full_path)
 
 
-class WorkspaceNotConfigured(tsrc.Error):
+class SyncError(Error):
+    pass
+
+
+class ClonerError(Error):
+    pass
+
+
+class FileSystemOperatorError(Error):
+    pass
+
+
+class RemoteSetterError(Error):
+    pass
+
+
+class WorkspaceNotConfigured(Error):
     def __init__(self, root_path: Path):
         super().__init__(
             f"Workspace in '{root_path}' is not configured. Please run `tsrc init`"
